Mock

Struct Mock 

pub struct Mock<'d> { /* private fields */ }
Mock RNG, containing invocation state and delegate closures.

Implementations

Source

impl<'d> Mock<'d>

pub fn with_next_u128(self, delegate: impl FnMut(&State) -> u128 + 'd) -> Self

Assigns a Rand::next_u128 delegate to the mock. I.e., when the Rand::next_u128 method is invoked on the mock (directly, or via another method), it will delegate to the given closure.

Examples
use tinyrand::Rand;
use tinyrand_alloc::Mock;
let mut mock = Mock::default()
    .with_next_u128(|_| 42);
assert_eq!(42, mock.next_usize());
assert_eq!(42, mock.next_u64());
assert_eq!(42, mock.next_u128());
pub fn with_next_bool( self, delegate: impl FnMut(Surrogate<'_, '_>, Probability) -> bool + 'd, ) -> Self

Assigns a Rand::next_bool delegate to the mock. I.e., when the Rand::next_bool method is invoked on the mock, it will delegate to the given closure.

Examples
use tinyrand::{Probability, Rand};
use tinyrand_alloc::Mock;
let mut mock = Mock::default()
    .with_next_bool(|_, _| true);
assert!(mock.next_bool(Probability::new(0.01)));
pub fn with_next_lim_u128( self, delegate: impl FnMut(Surrogate<'_, '_>, u128) -> u128 + 'd, ) -> Self

Assigns a Rand::next_lim_u128 delegate to the mock. I.e., when the Rand::next_lim_u128 method is invoked on the mock, it will delegate to the given closure. This delegate can be used to effectively mock Rand::next_lim and Rand::next_range methods.

Examples
use tinyrand::{Rand, RandRange};
use tinyrand_alloc::Mock;
let mut mock = Mock::default()
    .with_next_lim_u128(|_, _| 17);
assert_eq!(17, mock.next_lim_u64(66));
assert_eq!(27, mock.next_range(10..100u16));
pub fn state(&self) -> &State

Obtains the underlying mock state.