pub struct Surrogate<'a, 'd> { /* private fields */ }Expand description
Encapsulates the state of the mock and a reference to the next_u128 delegate, so
that it can be invoked from inside the mock by, for example, another delegate.
Implementations